<?php

namespace Teknisa\DF\Controllers;

use Teknisa\DF\Services\ImportacaoRateioService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error; 
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\XLS\Exception;

use Teknisa\DF\Controllers\TeknisaCrud;

class ImportacaoRateioController extends TeknisaCrud {
    
    const PERCENTUAL = 'P';
    const VALOR = 'V';
    
    protected $service;
    protected $titulosAPagarController;
    protected $titulosAReceberController;
    protected $nrorg;
    protected $environment;
    
    public function __construct($crudService, ParameterBag $parameterBag, ImportacaoRateioService $service) {
        $this->service = $service;
        parent::__construct($crudService, $parameterBag);
    }
    
    public function importRateio(DTO\Request $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            
            //Lê a tabela de rateio da planilha.
            $table = $this->service->readRateioTable($row, $row['TIPORATEIO']);
            
            //Formata dados das linhas
            $table->setRows($this->service->formatRateio($table, $row['TIPORATEIO']));
            
            
            //Valida os dados da tabela.
            $dbColumnValues = array('CDEMPRESA' => '02'/*$row['CDEMPRESA']*/);
            $this->service->validateRateioTable($table, $row['TIPORATEIO'], $dbColumnValues);
            
            $rows = $table->getRows();
            
            $dataSet = $this->service->buildRateioDataSet($row['ITENSRATEIO'],$row['TIPORATEIO'], $rows);
            
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('importRateio', $dataSet));
        }
        catch(Exception $e){
            $errors = $e->getErrors();
            $response->addDataSet(new DataSet('errors', $errors));
            $response->setError(new Error($e->getMessage(), 500));
        }
        catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
}